<?php

namespace Drupal\sape_links;

use Drupal\Component\Utility\Xss;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\HttpKernelInterface;

class SapeLinksMiddleware implements HttpKernelInterface {

  private HttpKernelInterface $httpKernel;

  /**
   * Constructor.
   */
  public function __construct(HttpKernelInterface $http_kernel) {
    $this->httpKernel = $http_kernel;
  }

  /**
   * {@inheritDoc}
   */
  public function handle(Request $request, $type = self::MASTER_REQUEST, $catch = TRUE): Response {
    $response = $this->httpKernel->handle($request, $type, $catch);

    if (str_starts_with($response->headers->get('content-type', ''), 'text/html')) {
      $content = $response->getContent();
      $content = str_replace('<!-- SAPE LINKS -->', $this->getSapeLinks(), $content);
      $response->setContent($content);
    }

    return $response;
  }

  /**
   * Return Sape links.
   */
  protected function getSapeLinks(): string {
    define('_SAPE_USER', '...');
    require_once($_SERVER['DOCUMENT_ROOT'] . '/' . _SAPE_USER . '/sape.php');
    $sape = new \SAPE_client(['charset' => 'utf-8']);
    return $sape->return_links();
  }

}
